#[non_exhaustive]pub enum ErrorKind {
Backend,
CreateConsole,
Spawn,
Resize,
Clear,
UnsupportedFeature,
InvalidSize,
Wait,
Kill,
Io,
}Expand description
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
Backend
Loading or validating the ConPTY backend failed.
CreateConsole
Creating the pseudoconsole or its pipes failed.
Spawn
Spawning the root process failed.
Resize
Resizing the pseudoconsole failed.
Clear
Clearing the pseudoconsole failed.
UnsupportedFeature
The selected backend does not provide a requested capability.
InvalidSize
A requested terminal size was invalid.
Wait
Waiting for the root process failed.
Kill
Terminating the process tree failed.
Io
Reading from or writing to a pseudoconsole pipe failed.